@@ -34,6 +34,13 @@ releases.</p>
   </tr>
 </table>
 
+<h1>v2.51 (2008-05-15)</h1>
+
+<ul>
+	<li class="start">Updated rpldhk and rpldev for Linux 2.6.25,
+		OpenBSD 4.3, FreeBSD 7.0, NetBSD 4.0</li>
+</ul>
+
 <h1>v2.50 (2008-01-01)</h1>
 
 <ul>
