@@ -1,6 +1,7 @@
 /*
  *	ttyrpld/user/replay.c
- *	Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2007
+ *	Copyright © CC Computer Consultants GmbH, 2004 - 2008
+ *	Contact: Jan Engelhardt <jengelh [at] computergmbh de>
  *
  *	This file is part of ttyrpld. ttyrpld is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
@@ -33,7 +34,6 @@
 	static_cast(void *, var - offsetof(type, member))
 #define MICROSECOND 1000000
 #define NANOSECOND  1000000000
-#define BUFSIZE     4096
 
 enum {
 	/* current follow mode state: */
@@ -64,7 +64,7 @@ struct {
 /* Functions */
 static int replay_file(int, const char *);
 static void e_proc(int, struct rpldsk_packet *, struct pctrl_info *, char *,
-	struct timeval *, long *);
+	struct rpltime *, long *);
 
 static unsigned long calc_ovcorr(unsigned long, int);
 static bool find_next_packet(int, const struct pctrl_info *);
@@ -73,11 +73,10 @@ static void getopt_jump(const struct HXoptcb *);
 static void getopt_msec(const struct HXoptcb *);
 static void getopt_skip(const struct HXoptcb *);
 static inline ssize_t read_nullfm(int, size_t);
-static ssize_t read_through(int, int, size_t);
 static ssize_t read_waitfm(int, void *, size_t, const struct pctrl_info *);
 static bool seek_to_end(int, const struct pctrl_info *);
 static void usleep_ovcorr(struct timeval *, long *);
-static void tv_delta(const struct timeval *, const struct timeval *,
+static void tv_delta(const struct rpltime *, const struct rpltime *,
 	struct timeval *);
 static inline unsigned long long tv2usec(const struct timeval *);
 static inline void usec2tv(unsigned long long, struct timeval *);
@@ -157,10 +156,10 @@ static int replay_file(int fd, const char *name)
 {
 	struct rpldsk_packet packet;
 	struct pctrl_info ps;
-	struct timeval stamp;
+	struct rpltime stamp;
 	ssize_t ret;
 	long skew = 0;
-	char tick = 0;
+	char tick = false;
 
 	if (Opt.follow == FM_LIVE && !seek_to_end(fd, &ps))
 		return 0;
@@ -254,7 +253,7 @@ static int replay_file(int fd, const char *name)
 }
 
 static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
-    char *tick, struct timeval *stamp, long *skew)
+    char *tick, struct rpltime *stamp, long *skew)
 {
 	if (i->sktype == PCTRL_SKPACK && i->skval-- > 0) {
 		/* Just skip, do not update tick/stamp/skew/delta */
@@ -263,10 +262,10 @@ static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
 	}
 
 	if (!*tick) {
-		/* No delay after the first packet has been read... */
-		++*tick;
+		/* No delay before the first packet has been replayed */
+		*tick = true;
 		if (i->skval > 0) {
-			memcpy(stamp, &p->time, sizeof(struct timeval));
+			memcpy(stamp, &p->time, sizeof(*stamp));
 			read_through(fd, STDOUT_FILENO, p->size);
 			return;
 		}
@@ -282,7 +281,7 @@ static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
 
 		if (i->sktype == PCTRL_SKTIME &&
 		    (i->skval -= tv2usec(&delta) / 1000) > 0) {
-			memcpy(stamp, &p->time, sizeof(struct timeval));
+			memcpy(stamp, &p->time, sizeof(*stamp));
 			read_through(fd, STDOUT_FILENO, p->size);
 			return;
 		}
@@ -302,7 +301,7 @@ static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
 	while (i->paused)
 		usleep(100000);
 
-	memcpy(stamp, &p->time, sizeof(struct timeval));
+	memcpy(stamp, &p->time, sizeof(*stamp));
 	read_through(fd, STDOUT_FILENO, p->size);
 
 	if (Opt.showtime) {
@@ -539,28 +538,6 @@ static void getopt_skip(const struct HXoptcb *cbi)
 	return;
 }
 
-static ssize_t read_through(int in, int out, size_t count)
-{
-	/*
-	 * Read from @in and directly give it to @out. This is like splice().
-	 */
-	char buf[BUFSIZE];
-	size_t rem = count;
-
-	while (rem > 0) {
-		ssize_t ret = read(in, buf, min_uint(BUFSIZE, rem));
-		if (ret < 0)
-			return 0;
-		write(out, buf, ret);
-		if (ret == rem)
-			break;
-		rem -= ret;
-		usleep(10000);
-	}
-
-	return count;
-}
-
 static inline ssize_t read_nullfm(int fd, size_t count)
 {
 	return G_skip(fd, count, Opt.follow != FM_NONE &&
@@ -615,14 +592,14 @@ static bool seek_to_end(int fd, const struct pctrl_info *ps)
 		 * not suitable, since ... it's just not designed to do what is
 		 * below, i.e.  non-blocking-until-EOF-call-it-something.
 		 */
-		char buf[BUFSIZE];
+		char buf[4096];
 
 		fcntl(fd, F_SETFL, fcntl(fd, F_GETFL) | O_NONBLOCK);
 		fprintf(stderr, _("Reading from something that does not "
 		        "support seeking (a pipe?),\n"
 		        "skipping to a position where reading would block\n"));
 
-		while (read(fd, buf, BUFSIZE) > 0)
+		while (read(fd, buf, sizeof(buf)) > 0)
 			;
 		if (errno != EAGAIN) {
 			perror("read()");
@@ -743,7 +720,7 @@ static void usleep_ovcorr(struct timeval *req, long *skew)
  *  Calculates the time difference between @past and @now and stores the result
  *  in @dest. All parameters in µs.
  */
-static void tv_delta(const struct timeval *past, const struct timeval *now,
+static void tv_delta(const struct rpltime *past, const struct rpltime *now,
     struct timeval *dest)
 {
 	unsigned long sec = now->tv_sec - past->tv_sec;
