@@ -1,6 +1,7 @@
 /*
  *	ttyrpld/user/rpld.c
- *	Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2007
+ *	Copyright © CC Computer Consultants GmbH, 2004 - 2007
+ *	Contact: Jan Engelhardt <jengelh [at] computergmbh de>
  *
  *	This file is part of ttyrpld. ttyrpld is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
@@ -373,7 +374,7 @@ static void log_open(struct tty *tty)
 	 * may contain _anything_, while EVT_MAGIC is fixed. See
 	 * share/ttyrpld.magic.)
 	 */
-	HX_strlcpy(buf, "RPL", sizeof(buf)); /* STRING FIXED */
+	HX_strlcpy(buf, "RPL2_50", sizeof(buf)); /* STRING FIXED */
 	p.event = EVT_MAGIC;
 	s = p.size = strlen(buf) + 1; /* include '\0' in stream */
 	SWAB1(&p.size);
@@ -706,7 +707,8 @@ static bool find_devnode_dive(uint32_t id, char *dest, size_t len,
 	}
 
 	while ((de = HXdir_read(dx)) != NULL) {
-		if (*de == '.')
+		if (*de == '.' || strcmp(de, "stdout") == 0 ||
+		    strcmp(de, "stderr") == 0 || strcmp(de, "stdin") == 0)
 			continue;
 		snprintf(buf, sizeof(buf), "%s/%s", dir, de);
 
@@ -825,7 +827,7 @@ static bool read_config(const char *file)
 	         .cb = getopt_username},
 		HXOPT_TABLEEND,
 	};
-	return HX_shconfig(file, config_table) <= 0;
+	return HX_shconfig(file, config_table) > 0;
 }
 
 static bool read_config_bp(const char *app_path, const char *file)
